pub fn prover() -> &'static LocalTxProverExpand description
Returns the shared Sapling prover.
Parsing the bundled Sapling parameters takes time, so callers that build Sapling outputs share this prover instead of parsing the parameters again.
pub fn prover() -> &'static LocalTxProverReturns the shared Sapling prover.
Parsing the bundled Sapling parameters takes time, so callers that build Sapling outputs share this prover instead of parsing the parameters again.